;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "git-modes" "20260601.1550"
  "Major modes for editing Git configuration files."
  '((emacs  "28.1")
    (compat "31.0"))
  :url "https://github.com/magit/git-modes"
  :commit "f291a4cc4a8b02a25d5cf93b4ab6af29e6f060d9"
  :revdesc "f291a4cc4a8b"
  :keywords '("convenience" "vc" "git")
  :authors '(("Sebastian Wiesner" . "lunaryorn@gmail.com")
             ("Rüdiger Sonderfeld" . "ruediger@c-plusplus.net")
             ("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev")))
